==> develocity-gradle-plugin-3.19.2-sources.jar: com/gradle/develocity/agent/gradle/test/TestDistributionConfiguration.java <==
package com.gradle.develocity.agent.gradle.test;

import com.gradle.obfuscation.Keep;
import org.gradle.api.Action;
import org.gradle.api.provider.Property;
import org.gradle.api.provider.SetProperty;
import org.gradle.api.tasks.Input;
import org.gradle.api.tasks.Internal;

import java.time.Duration;

/**
 * The configuration for Test Distribution.
 * <p>
 * Please refer to the
 * <a href="https://gradle.com/help/test-distribution-gradle-configuration/">user manual</a> for details.
 *
 * @since 3.17
 */
@Keep
public interface TestDistributionConfiguration {

    /**
     * Whether test distribution is enabled.
     * <p>
     * This setting defaults to {@code false}.
     *
     * @return whether test distribution is enabled
     */
    @Internal
    Property<Boolean> getEnabled();

    /**
     * The number of executors to use for running tests on this machine.
     * <p>
     * This setting defaults to {@link org.gradle.api.tasks.testing.Test#getMaxParallelForks() maxParallelForks}.
     * The number of local executors that can be used is limited by
     * {@link org.gradle.StartParameter#getMaxWorkerCount() maxWorkerCount}.
     * Setting this to 0 causes tests to be only executed on the remote test execution infrastructure.
     *
     * @return the number of local executors to use.
     */
    @Internal
    Property<Integer> getMaxLocalExecutors();

    /**
     * The number of remote executors that should be requested from the remote test execution infrastructure in order
     * run the tests of this test task.
     * <p>
     * This setting has no default value meaning that as much remote executors as are possible should be requested.
     * Setting this to zero causes tests to be only executed using local executors.
     * <p>
     * Note that setting this to a fixed number doesn't necessarily mean that this test task will get that many remote
     * executors. It's just an indicator for the remote test execution infrastructure for how many executors it should
     * try to make available to this test task. It may well be that this test task does not get any remote executors at
     * all e.g. if no executors matching all {@link #getRequirements() requirements} become available.
     *
     * @return the number of remote executors to request.
     */
    @Internal
    Property<Integer> getMaxRemoteExecutors();

    /**
     * If enabled, remote executors are tried first, falling back to local ones after {@link #getWaitTimeout() waitTimeout} expires.
     * <p>
     * This setting defaults to {@code false}.
     *
     * @return whether remote executors should be preferred over local executors
     */
    @Internal
    Property<Boolean> getRemoteExecutionPreferred();

    /**
     * The duration the build waits for the remote test execution infrastructure to respond.
     * <p>
     * This setting defaults to 30 seconds and must be set to a positive value.
     *
     * @return the wait timeout duration.
     */
    @Internal
    Property<Duration> getWaitTimeout();

    /**
     * If enabled, the tests will be retried in the same JVM.
     * <p>
     * This setting defaults to {@code true}.
     *
     * @return whether to retry tests in the same JVM
     */
    @Internal
    Property<Boolean> getRetryInSameJvm();

    /**
     * The requirements that need to be fulfilled by executors in order to execute the tests of this test task.
     * <p>
     * Requirements are matched against the capabilities of the connected remote executors. Only those executors
     * having all required capabilities will be assigned for running the tests of this task. Local executors are
     * assumed to provide any capabilities. This means that no matter the requirements, local executors will always
     * be used as long as {@link #getMaxLocalExecutors() maxLocalExecutors} is greater than 0.
     * <p>
     * A requirement String may only contain alphanumeric characters, dashes, underscores, periods, and a single equals
     * sign. Apart from that, users are free in how they want to structure requirements. The recommendation is to use
     * key value pairs or tag-like requirements:
     * <pre>
     * test {
     *     distribution {
     *         requirements = ['os=linux', 'db=mysql', 'EXECUTOR_POOL_1']
     *     }
     * }
     * </pre>
     * <p>
     * The requirements will always have the value {@code jdk=<version>} added with {@code <version>} being derived from
     * the executable set on this test task via {@link org.gradle.api.tasks.testing.Test#getExecutable()}.
     *
     * @return the requirements remote executors need to fulfill for running tests of this test task.
     */
    @Input
    SetProperty<String> getRequirements();

    /**
     * Whether Test Distribution should fall back to regular execution, if JUnit Platform is not enabled.
     */
    @Internal
    Property<Boolean> getFallbackToRegularExecutionOnMissingPrerequisites();

    /**
     * The set of criteria for specifying which tests must always run on local executors.
     */
    @Internal
    RestrictedExecutionCriteria getLocalOnly();

    /**
     * The set of criteria for specifying which tests must always run on local executors.
     */
    void localOnly(Action<? super RestrictedExecutionCriteria> action);

    /**
     * The set of criteria for specifying which tests must always run on remote executors.
     */
    @Internal
    RestrictedExecutionCriteria getRemoteOnly();

    /**
     * The set of criteria for specifying which tests must always run on remote executors.
     */
    void remoteOnly(Action<? super RestrictedExecutionCriteria> action);

    /**
     * A set of criteria for specifying which tests must run on local or remote executors only.
     * <p>
     * By default, tests have no restriction where they can run.
     */
    @Keep
    interface RestrictedExecutionCriteria {

        /**
         * The patterns used to include tests based on their class name.
         * <p>
         * The pattern string matches against qualified class names.
         * It may contain '*' characters, which match zero or more of any character.
         * <p>
         * A class name only has to match one pattern to be included.
         */
        SetProperty<String> getIncludeClasses();

        /**
         * The patterns used to include tests based on their class level annotations.
         * <p>
         * The pattern string matches against the qualified class names of a test class's annotations.
         * It may contain '*' characters, which match zero or more of any character.
         * <p>
         * A class need only have one annotation matching any of the patterns to be included.
         * <p>
         * Annotations present on super classes that are {@code @Inherited} are considered when inspecting subclasses.
         */
        SetProperty<String> getIncludeAnnotationClasses();
    }
}

==> develocity-gradle-plugin-4.0.1-sources.jar: com/gradle/develocity/agent/gradle/test/TestDistributionConfiguration.java <==
package com.gradle.develocity.agent.gradle.test;

import com.gradle.obfuscation.Keep;
import org.gradle.api.Action;
import org.gradle.api.provider.Property;
import org.gradle.api.provider.SetProperty;
import org.gradle.api.tasks.Input;
import org.gradle.api.tasks.Internal;

import java.time.Duration;

/**
 * The configuration for Test Distribution.
 * <p>
 * Please refer to the
 * <a href="https://gradle.com/help/test-distribution-gradle-configuration/">user manual</a> for details.
 *
 * @since 3.17
 */
@Keep
public interface TestDistributionConfiguration {

    /**
     * Whether test distribution is enabled.
     * <p>
     * This setting defaults to {@code false}.
     *
     * @return whether test distribution is enabled
     */
    @Internal
    Property<Boolean> getEnabled();

    /**
     * The number of executors to use for running tests on this machine.
     * <p>
     * This setting defaults to {@link org.gradle.api.tasks.testing.Test#getMaxParallelForks() maxParallelForks}.
     * The number of local executors that can be used is limited by
     * {@link org.gradle.StartParameter#getMaxWorkerCount() maxWorkerCount}.
     * Setting this to 0 causes tests to be only executed on the remote test execution infrastructure.
     *
     * @return the number of local executors to use.
     */
    @Internal
    Property<Integer> getMaxLocalExecutors();

    /**
     * The number of remote executors that should be requested from the remote test execution infrastructure in order
     * run the tests of this test task.
     * <p>
     * This setting has no default value meaning that as much remote executors as are possible should be requested.
     * Setting this to zero causes tests to be only executed using local executors.
     * <p>
     * Note that setting this to a fixed number doesn't necessarily mean that this test task will get that many remote
     * executors. It's just an indicator for the remote test execution infrastructure for how many executors it should
     * try to make available to this test task. It may well be that this test task does not get any remote executors at
     * all e.g. if no executors matching all {@link #getRequirements() requirements} become available.
     *
     * @return the number of remote executors to request.
     */
    @Internal
    Property<Integer> getMaxRemoteExecutors();

    /**
     * If enabled, remote executors are tried first, falling back to local ones after {@link #getWaitTimeout() waitTimeout} expires.
     * <p>
     * This setting defaults to {@code false}.
     *
     * @return whether remote executors should be preferred over local executors
     */
    @Internal
    Property<Boolean> getRemoteExecutionPreferred();

    /**
     * The duration the build waits for the remote test execution infrastructure to respond.
     * <p>
     * This setting defaults to 30 seconds and must be set to a positive value.
     *
     * @return the wait timeout duration.
     */
    @Internal
    Property<Duration> getWaitTimeout();

    /**
     * If enabled, the tests will be retried in the same JVM.
     * <p>
     * This setting defaults to {@code true}.
     *
     * @return whether to retry tests in the same JVM
     */
    @Internal
    Property<Boolean> getRetryInSameJvm();

    /**
     * The requirements that need to be fulfilled by executors in order to execute the tests of this test task.
     * <p>
     * Requirements are matched against the capabilities of the connected remote executors. Only those executors
     * having all required capabilities will be assigned for running the tests of this task. Local executors are
     * assumed to provide any capabilities. This means that no matter the requirements, local executors will always
     * be used as long as {@link #getMaxLocalExecutors() maxLocalExecutors} is greater than 0.
     * <p>
     * A requirement String may only contain alphanumeric characters, dashes, underscores, periods, and a single equals
     * sign. Apart from that, users are free in how they want to structure requirements. The recommendation is to use
     * key value pairs or tag-like requirements:
     * <pre>
     * test {
     *     distribution {
     *         requirements = ['os=linux', 'db=mysql', 'EXECUTOR_POOL_1']
     *     }
     * }
     * </pre>
     * <p>
     * The requirements will always have the value {@code jdk=<version>} added with {@code <version>} being derived from
     * the executable set on this test task via {@link org.gradle.api.tasks.testing.Test#getExecutable()}.
     *
     * @return the requirements remote executors need to fulfill for running tests of this test task.
     */
    @Input
    SetProperty<String> getRequirements();

    /**
     * Whether Test Distribution should fall back to regular execution, if JUnit Platform is not enabled.
     */
    @Internal
    Property<Boolean> getFallbackToRegularExecutionOnMissingPrerequisites();

    /**
     * The set of criteria for specifying which tests must always run on local executors.
     */
    @Internal
    RestrictedExecutionCriteria getLocalOnly();

    /**
     * The set of criteria for specifying which tests must always run on local executors.
     */
    void localOnly(Action<? super RestrictedExecutionCriteria> action);

    /**
     * The set of criteria for specifying which tests must always run on remote executors.
     */
    @Internal
    RestrictedExecutionCriteria getRemoteOnly();

    /**
     * The set of criteria for specifying which tests must always run on remote executors.
     */
    void remoteOnly(Action<? super RestrictedExecutionCriteria> action);

    /**
     * The maximal number of remote executor failures that will be tolerated, before attempting to fall back to local execution
     */
    @Internal
    Property<Integer> getMaxRecoverableFailures();

    /**
     * A set of criteria for specifying which tests must run on local or remote executors only.
     * <p>
     * By default, tests have no restriction where they can run.
     */
    @Keep
    interface RestrictedExecutionCriteria {

        /**
         * The patterns used to include tests based on their class name.
         * <p>
         * The pattern string matches against qualified class names.
         * It may contain '*' characters, which match zero or more of any character.
         * <p>
         * A class name only has to match one pattern to be included.
         */
        SetProperty<String> getIncludeClasses();

        /**
         * The patterns used to include tests based on their class level annotations.
         * <p>
         * The pattern string matches against the qualified class names of a test class's annotations.
         * It may contain '*' characters, which match zero or more of any character.
         * <p>
         * A class need only have one annotation matching any of the patterns to be included.
         * <p>
         * Annotations present on super classes that are {@code @Inherited} are considered when inspecting subclasses.
         */
        SetProperty<String> getIncludeAnnotationClasses();
    }
}
